Show method for PhysioEvents
Value
Returns NULL invisibly; called for the side effect of printing
a compact summary of the events to the console.
See also
PhysioEvents for the constructor,
nEvents for event count
Show method for PhysioEvents
Returns NULL invisibly; called for the side effect of printing
a compact summary of the events to the console.
PhysioEvents for the constructor,
nEvents for event count