Skip to contents

Sample times of a stream on the shared clock

Usage

streamTimeIndex(x, stream = NULL)

Arguments

x

A MultiRatePhysioExperiment.

stream

Stream name (or NULL for a named list of all streams).

Value

Numeric time vector (seconds from t0) for the stream, or a named list of such vectors when stream is NULL.

See also