Skip to contents

Computes a time vector for the default assay using the object's sampling rate.

Usage

timeIndex(x)

Arguments

x

A PhysioExperiment instance.

Value

Numeric vector of time points in seconds.

References

Oostenveld R, Fries P, Maris E, Schoffelen JM (2011). "FieldTrip: Open source software for advanced analysis of MEG, EEG, and invasive electrophysiological data." Computational Intelligence and Neuroscience, 2011, 156869.

See also

samplingRate for the sampling rate, duration for signal duration, timeToSamples for converting times to sample indices

Examples

pe <- PhysioExperiment(
  assays = list(raw = matrix(rnorm(40), nrow = 10, ncol = 4)),
  samplingRate = 100
)
head(timeIndex(pe))
#> [1] 0.00 0.01 0.02 0.03 0.04 0.05