Fits MVAR models over a range of orders and returns the order minimising the
Akaike (AIC) or Bayesian (BIC) information criterion. For an m-channel model
of order p with n effective samples the criteria are
n log det(Sigma_p) + 2 m^2 p (AIC) and
n log det(Sigma_p) + log(n) m^2 p (BIC).
Arguments
- X
A numeric matrix (
time x channels).- max_order
Maximum order to consider (default: 20).
- criterion
"bic"(default) or"aic".- method
Estimator passed to
.fitMVAR(default "ols").